@@ -1,12 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelSQL, ModelView, fields
+from trytond.model import ModelSQL, ModelView, DeactivableMixin, fields
 from trytond.pyson import Eval
 
-__all__ = ['Service']
 
-
-class Service(ModelSQL, ModelView):
+class Service(DeactivableMixin, ModelSQL, ModelView):
     "Subscription Service"
     __name__ = 'sale.subscription.service'
 
